
information = {
        'header1':'## What is it ?',
        'what':'The International Space Station (ISS) is a modular space station (habitable artificial satellite) in low Earth orbit. It is a multinational collaborative project involving five participating space agencies: NASA (United States), Roscosmos (Russia), JAXA (Japan), ESA (Europe), and CSA (Canada). The ownership and use of the space station is established by intergovernmental treaties and agreements. The station serves as a microgravity and space environment research laboratory in which scientific research is conducted in astrobiology, astronomy, meteorology, physics, and other fields. The ISS is suited for testing the spacecraft systems and equipment required for possible future long-duration missions to the Moon and Mars.',
        'intro_source':"<h6 style='text-align: right;'>Source: <a href=\"https://en.wikipedia.org/wiki/International_Space_Station\">Wikipedia</a></h6>",
        'header2':'## Some facts !',
        'tech_spec':'''<style>\
                        table, th, td {\
                            border: 1px solid black;\
                            border-collapse: collapse;\
                            background-color: #f1f1f1;\
                            }\
                        th, td {\
                            padding: 15px;\
                            text-align: left;\
                            }\
                        </style>\
                        <table>\
                            <tr><th>Specification</th>              <th>Value</th></tr>\
                            <tr><td>Launch</td>						<td>20 November 1998; 22 years ago</td></tr>\
                            <tr><td>Launch pad</td>				    <td>Baikonur, Site 1/5 and Site 81/23, Kennedy, LC-39 and CCAFS SLC-41 (future)</td></tr>\
                            <tr><td>Mass</td>						<td>419,725 kg</td></tr>\
                            <tr><td>Length</td>						<td>73 m</td></tr>\
                            <tr><td>Width</td>						<td>109 m</td></tr>\
                            <tr><td>Pressurised volume</td>			<td>915.6 m<sup>3</sup></td></tr>\
                            <tr><td>Atmospheric pressure</td>		<td>101.3 kPa or 1.0 atm [oxygen 21%, nitrogen 79%]</td></tr>\
                            <tr><td>Perigee altitude</td>			<td>418 km</td></tr>\
                            <tr><td>Apogee altitude</td>			<td>422 km</td></tr>\
                            <tr><td>Orbital inclination</td>		<td>51.63°</td></tr>\
                            <tr><td>Orbital speed</td>				<td>~ 7.66 km/s or 27,600 km/h</td></tr>\
                            <tr><td>Orbital period</td>				<td>92.68 minutes</td></tr>\
                            <tr><td>Orbits per day</td>				<td>15.54</td></tr>\
                            <tr><td>Days in orbit</td>				<td>22 years, 2 months, 30 days</td></tr>\
                            <tr><td>Days occupied</td>				<td>20 years, 3 months, 17 days</td></tr>\
                            <tr><td>No. of orbits</td>				<td>125,964 as of December 2020</td></tr>\
                            <tr><td>Orbital decay</td>				<td>2 km/month</td></tr>\
                            </table>'''
}
                            